@@ -5,7 +5,7 @@ use warnings;
 use warnings qw(FATAL utf8); # Fatalize encoding glitches.
 
 our $Debug   = 0;
-our $VERSION = '1.27';
+our $VERSION = '1.28';
 
 use File::Slurp::Tiny 'read_lines';
 
@@ -68,7 +68,7 @@ sub _add_daughters_wrapper {
       ($daughter->name() || $daughter),
       ($mother->name()   || $mother)     if $Debug > 1;
 
-    die "Mother can't be its own daughter\n" if $mother eq $daughter;
+    die 'Mother (' . $mother -> name . ") can't be its own daughter\n" if $mother eq $daughter;
 
     die "$daughter (" . ($daughter->name || 'no_name') .
       ") is an ancestor of $mother (" . ($mother->name || 'no_name') .
@@ -1724,6 +1724,11 @@ Tree::DAG_Node - An N-ary tree
 	$root -> add_daughter(Tree::DAG_Node -> new({name => 'two', attributes => {} }) );
 	$root -> add_daughter(Tree::DAG_Node -> new({name => 'three'}) ); # Attrs default to {}.
 
+Or:
+
+	my($count) = 0;
+	my($tree)  = Tree::DAG_Node -> new({name => 'Root', attributes => {'uid' => $count} });
+
 Or:
 
 	my $root = Tree::DAG_Node -> new();
@@ -1737,6 +1742,11 @@ Or:
 	$new_daughter -> attributes({uid => 1});
 	...
 
+Lastly, for fancy wrappers - called _add_daughter() - around C<new()>, see these modules:
+L<Marpa::Demo::StringParser> and L<GraphViz2::Marpa>. Both of these modules use L<Moo>.
+
+See scripts/*.pl for other samples.
+
 =head2 Using with utf-8 data
 
 read_tree($file_name) works with utf-8 data. See t/read.tree.t and t/tree.utf8.attributes.txt.
